@@ -28,29 +28,37 @@ class DamonSnapshot:
     end_time = None
     regions = None
     total_bytes = None
+    damos_stats = None
 
     def update_total_bytes(self):
         self.total_bytes = sum([r.size() for r in self.regions])
 
-    def __init__(self, start_time, end_time, regions, total_bytes):
+    def __init__(self, start_time, end_time, regions, total_bytes, damos_stats=None):
         self.start_time = start_time
         self.end_time = end_time
         self.regions = regions
         self.total_bytes = total_bytes
         if self.total_bytes is None:
             self.update_total_bytes()
+        self.damos_stats = damos_stats
 
     @classmethod
     def from_kvpairs(cls, kv):
+        damos_stats = None
+        if 'damos_stats' in kv and kv['damos_stats'] is not None:
+            damos_stats = _damon.DamosStats.from_kvpairs(kv['damos_stats'])
         return DamonSnapshot(
                 _damo_fmt_str.text_to_ns(kv['start_time']),
                 _damo_fmt_str.text_to_ns(kv['end_time']),
                 [_damon.DamonRegion.from_kvpairs(r) for r in kv['regions']],
                 _damo_fmt_str.text_to_bytes(kv['total_bytes'])
                 if 'total_bytes' in kv and kv['total_bytes'] is not None
-                else None)
+                else None, damos_stats)
 
     def to_kvpairs(self, raw=False):
+        damos_stats_kv = None
+        if self.damos_stats is not None:
+            damos_stats_kv = self.damos_stats.to_kvpairs(raw)
         return collections.OrderedDict([
             ('start_time', _damo_fmt_str.format_time_ns_exact(
                 self.start_time, raw)),
@@ -59,6 +67,7 @@ class DamonSnapshot:
             ('regions', [r.to_kvpairs() for r in self.regions]),
             ('total_bytes', _damo_fmt_str.format_sz(self.total_bytes, raw)
                 if self.total_bytes is not None else None),
+            ('damos_stats', damos_stats_kv)
             ])
 
 class DamonRecord:
@@ -1206,7 +1215,7 @@ def tried_regions_to_snapshot(scheme, intervals, merge_regions):
         total_bytes = None
 
     return DamonSnapshot(snapshot_start_time_ns, snapshot_end_time_ns, regions,
-            total_bytes)
+            total_bytes, scheme.stats)
 
 def tried_regions_to_records_of(idxs, merge_regions):
     '''idxs: list of kdamond/context/scheme indices to get records for.  If it
@@ -1304,6 +1313,13 @@ def update_get_snapshot_records(kdamond_idxs, scheme_idxs,
     while err is not None and nr_tries < 5:
         nr_tries += 1
 
+        # todo: update schemes stats only if really required
+        err = _damon.update_schemes_stats(kdamond_idxs)
+        if err is not None:
+            time.sleep(random.rndrange(
+                2**(nr_tries - 1), 2**nr_tries) / 100)
+            continue
+
         # todo: update tuned intervals only if auto-tuning is ongoing
         err = _damon.update_tuned_intervals(kdamond_idxs)
         if err is not None:
@@ -1461,6 +1477,8 @@ def filter_records_by_temperature(records, temperature_ranges,
         for snapshot in record.snapshots:
             filtered_regions = []
             for region in snapshot.regions:
+                region.nr_accesses.add_unset_unit(record.intervals)
+                region.age.add_unset_unit(record.intervals)
                 temperature = damo_report_access.temperature_of(
                         region, temperature_weights)
                 for min_t, max_t in temperature_ranges:
