@@ -23,11 +23,25 @@ import damo_pa_layout
 
 # Kdamonds construction from command line arguments
 
-def merge_cont_ranges(ranges):
+def range_overlap_or_contig(range1, range2):
+    s1, e1 = range1
+    s2, e2 = range2
+    if e1 == s2 or e2 == s1:
+        return True
+    if e1 <= s2:
+        return False
+    if e2 <= s1:
+        return False
+    return True
+
+def merge_ranges(ranges):
+    ranges.sort(key=lambda r: r[0])
     merged_ranges = []
     for start, end in ranges:
-        if len(merged_ranges) > 0 and merged_ranges[-1][1] == start:
-            merged_ranges[-1][1] = end
+        if len(merged_ranges) > 0 and range_overlap_or_contig(
+                merged_ranges[-1], [start, end]):
+            merged_ranges[-1] = [min(merged_ranges[-1][0], start),
+                                 max(merged_ranges[-1][1], end)]
         else:
             merged_ranges.append([start, end])
     return merged_ranges
@@ -55,7 +69,7 @@ def init_regions_for(args):
                     args.numa_node)
             if err != None:
                 return None, err
-            init_regions = merge_cont_ranges(init_regions)
+            init_regions = merge_ranges(init_regions)
         else:
             init_regions = [damo_pa_layout.default_paddr_region()]
         try:
@@ -692,7 +706,8 @@ def set_monitoring_attrs_argparser(parser, hide_help=False):
             '--monitoring_intervals_goal', nargs=4,
             metavar=('<access_bp>', '<aggrs>', '<min_sample_us>',
                      '<max_sample_us>'), default=['0%', '0', '0us', '0us'],
-            help='monitoring intervals auto-tuning goal')
+            help='monitoring intervals auto-tuning goal'
+            if not hide_help else argparse.SUPPRESS)
     parser.add_argument('--monitoring_nr_regions_range', nargs=2,
                         metavar=('<min>', '<max>'), default=[10, 1000],
                         help='min/max number of monitoring regions'
@@ -718,7 +733,11 @@ def set_monitoring_argparser(parser, hide_help=False):
 def set_damos_argparser(parser, hide_help):
     parser.add_argument('--damos_action', metavar='<action>', nargs='+',
                         action='append', default=[],
-                        help='damos action to apply to the target regions'
+                        help=' '.join([
+                            'damos action to apply to the target regions.',
+                            '<action> should be {%s}.' %
+                            ','.join(_damon.damos_actions),
+                            ])
                         if not hide_help else argparse.SUPPRESS)
     parser.add_argument('--damos_sz_region', metavar=('<min>', '<max>'),
                         nargs=2, default=[], action='append',
@@ -738,15 +757,15 @@ def set_damos_argparser(parser, hide_help):
                         action='append', default=[],
                         help='the apply interval for the scheme'
                         if not hide_help else argparse.SUPPRESS)
+    damos_quotas_help = ' '.join([
+        'damos quotas (<time (ms)> [<size (bytes)> [<reset interval (ms)>',
+        '[<size priority weight (permil)>',
+        '[<access rate priority weight> (permil)',
+        '[<age priority weight> (permil)]]]]])'])
     parser.add_argument(
             '--damos_quotas', default=[],
             metavar='<quota parameter>', nargs='+', action='append',
-            help=' '.join([
-            'damos quotas (<time (ms)> [<size (bytes)> [<reset interval (ms)>',
-                '[<size priority weight (permil)>',
-                '[<access rate priority weight> (permil)',
-                '[<age priority weight> (permil)]]]]])'])
-            if not hide_help else argparse.SUPPRESS)
+            help=argparse.SUPPRESS)
     parser.add_argument('--damos_quota_interval', default=[],
                         metavar='<milliseconds>', action='append',
                         help='quota reset interval'
@@ -786,22 +805,22 @@ def set_damos_argparser(parser, hide_help):
     parser.add_argument(
             '--damos_filter', nargs='+', action='append',
             default=[],
-            metavar='<filter argument>',
-            help='damos filter (type, matching, and optional arguments)'
-            if not hide_help else argparse.SUPPRESS)
+            metavar='<<allow|reject> [none] <type> [option]...>',
+            help='damos filter' if not hide_help else argparse.SUPPRESS)
     parser.add_argument(
             '--damos_filter_out', nargs='+', action='append',
             default=[],
             metavar='<filter argument>',
-            help='damos filter (matching, type, and optional arguments)'
-            if not hide_help else argparse.SUPPRESS)
+            help=argparse.SUPPRESS)
+            # help='damos filter (matching, type, and optional arguments)'
+            # if not hide_help else argparse.SUPPRESS)
     parser.add_argument(
             '--damos_nr_filters', type=int, nargs='+', default=[],
             metavar='<integer>',
             help='number of filters for each scheme (in order)'
             if not hide_help else argparse.SUPPRESS)
 
-def set_argparser(parser, add_record_options, min_help):
+def set_damon_params_argparser(parser, min_help):
     set_monitoring_argparser(parser, min_help)
     set_damos_argparser(parser, min_help)
     parser.add_argument('-c', '--schemes', metavar='<json string or file>',
@@ -817,11 +836,14 @@ def set_argparser(parser, add_record_options, min_help):
                 'The implicit monitoring requests.',
                 'It could be a command, process id, special keywords, or full',
                 'DAMON parameters (same to that for --kdamonds)']))
+    set_monitoring_attrs_pinpoint_argparser(parser, hide_help=True)
+
+def set_argparser(parser, add_record_options, min_help):
+    set_damon_params_argparser(parser, min_help)
     if add_record_options:
         parser.add_argument('-o', '--out', metavar='<file path>', type=str,
                 default='damon.data', help='output file path')
     set_common_argparser(parser)
-    set_monitoring_attrs_pinpoint_argparser(parser, min_help)
     if min_help:
         if parser.epilog is None:
             parser.epilog = ''
