@@ -242,6 +242,11 @@ def write_quota_goal_dir(dir_path, goal):
         if err is not None:
             return err
 
+    if goal.has_nid():
+        err = _damo_fs.write_file(os.path.join(dir_path, 'nid'), '%d' % goal.nid)
+        if err is not None:
+            return err
+
     err = _damo_fs.write_file(
             os.path.join(dir_path, 'target_value'),
             '%d' % goal.target_value)
@@ -582,6 +587,7 @@ def files_content_to_quota_goals(files_content):
             goals.append(
                     _damon.DamosQuotaGoal(
                         metric=goal_kv['target_metric'].strip(),
+                        nid=goal_kv['nid'] if 'nid' in goal_kv else None,
                         target_value=goal_kv['target_value'],
                         current_value=goal_kv['current_value']))
         else:
@@ -985,6 +991,26 @@ def update_supported_features():
 
     # todo: check unmapped filter support by trying writing it to filter type
 
+    if feature_supports['schemes_quota_goals'] is True:
+        kdamonds_for_feature_check = [
+                _damon.Kdamond(
+                    state=None, pid=None, contexts=[
+                        _damon.DamonCtx(
+                            schemes=[_damon.Damos(
+                                quotas=_damon.DamosQuotas(
+                                    goals=[_damon.DamosQuotaGoal()])
+                                )])])]
+        err = stage_kdamonds(kdamonds_for_feature_check)
+        if err is not None:
+            print('staging damos goal feature check purpose kdamond failed')
+            stage_kdamonds(orig_kdamonds)
+            exit(1)
+
+        if os.path.isfile(
+                os.path.join(scheme_dir_of(0, 0, 0), 'quotas', 'goals', '0',
+                             'nid')):
+            feature_supports['schemes_quota_goal_node_mem_used_free'] = True
+
     avail_ops, err = _avail_ops()
     if err == None:
         for ops in ['vaddr', 'paddr', 'fvaddr']:
