@@ -23,9 +23,7 @@ import damo_record_info
 import damo_replay
 import damo_report
 import damo_schemes
-import damo_show
 import damo_start
-import damo_status
 import damo_stop
 import damo_tune
 import damo_validate
@@ -86,18 +84,6 @@ subcmds = [
         _damo_subcmds.DamoSubCmd(name='pa_layout',
             module=damo_pa_layout,
             msg='show physical address layout'),
-
-        # Will be deprecated
-        _damo_subcmds.DamoSubCmd(name='show', module=damo_show,
-            msg=' '.join(
-                ['show monitored access pattern',
-                 '(Will be DEPRECATED; Use "damo report access" instead.)'])),
-        _damo_subcmds.DamoSubCmd(name='status',
-            module=damo_status,
-            msg=' '.join(
-                ['show DAMON status',
-                 '(Will be DEPRECATED; Use "damo report damon" instead.)'])),
-
         ]
 
 class SubCmdHelpFormatter(argparse.RawDescriptionHelpFormatter):
